@@ -3,7 +3,7 @@ from dagster._core.utils import check_dagster_package_version
 from .executor import k8s_job_executor
 from .job import DagsterK8sJobConfig, construct_dagster_k8s_job
 from .launcher import K8sRunLauncher
-from .ops.k8s_job_op import k8s_job_op
+from .ops import execute_k8s_job, k8s_job_op
 from .version import __version__
 
 check_dagster_package_version("dagster-k8s", __version__)
